AskIntDialogParams class sealed

Annotations
  • @freezed

Constructors

AskIntDialogParams({@Default.new("") String placeholder, @Default.new("") String title, @Default.new("Confirm") String okBtnText, @Default.new("Cancel") String cancelBtnText, bool disableOkButton(int value)?, String? errorMessage(int value)?, TextStyle? okButtonTextStyle, TextStyle? cancelButtonTextStyle})
const
factory

Properties

cancelBtnText → String
no setterinherited
cancelButtonTextStyle → TextStyle?
no setterinherited
copyWith → $AskIntDialogParamsCopyWith<AskIntDialogParams>
Create a copy of AskIntDialogParams with the given fields replaced by the non-null parameter values.
no setterinherited
disableOkButton → bool Function(int value)?
no setterinherited
errorMessage → String? Function(int value)?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
okBtnText → String
no setterinherited
okButtonTextStyle → TextStyle?
no setterinherited
placeholder → String
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited