DartTypeModel class sealed

Available extensions
Annotations
  • @freezed

Constructors

DartTypeModel.bool(bool value)
const
factory
DartTypeModel.createFrom(dynamic data)
factory
DartTypeModel.dynamic(dynamic value)
const
factory
DartTypeModel.fromJson(Map<String, dynamic> json)
factory
DartTypeModel.json(Map<String, dynamic> value)
const
factory
DartTypeModel.jsonString(String jsonString)
const
factory
DartTypeModel.list(List value)
const
factory
DartTypeModel.nil()
const
factory
DartTypeModel.num(num value)
const
factory
DartTypeModel.string(String value)
const
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

form<T>(T call(dynamic e)) → List<T>

Available on DartTypeModel, provided by the DartTypeModelEx extension

formWithField<T>(String field, T call(dynamic e)) → List<T>

Available on DartTypeModel, provided by the DartTypeModelEx extension

getFieldByJson<T>(String key) → T?

Available on DartTypeModel, provided by the DartTypeModelEx extension

isBool() → bool

Available on DartTypeModel, provided by the DartTypeModelEx extension

isJson() → bool

Available on DartTypeModel, provided by the DartTypeModelEx extension

isList() → bool

Available on DartTypeModel, provided by the DartTypeModelEx extension

isNull() → bool

Available on DartTypeModel, provided by the DartTypeModelEx extension

isString() → bool

Available on DartTypeModel, provided by the DartTypeModelEx extension

isTrue() → bool

Available on DartTypeModel, provided by the DartTypeModelEx extension

model<T>(T call(Map<String, dynamic> e)) → T

Available on DartTypeModel, provided by the DartTypeModelEx extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this DartTypeModel to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
whenOrNull<T>({T? string(String value)?, T? num(num value)?, T? bool(bool value)?, T? list(List value)?, T? json(Map<String, dynamic> value)?, T? dynamic(dynamic value)?, T? nil()?, T? jsonStringCall(String value)?}) → T?

Available on DartTypeModel, provided by the DartTypeModelEx extension

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

freezedFromJson(dynamic v) → DartTypeModel