PictureSelectionItemModel class sealed

图片选择器模型

Available extensions
Annotations
  • @freezed

Constructors

PictureSelectionItemModel.file({required File file})
factory
PictureSelectionItemModel.network({required String url})
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
imageProvider → ImageProvider<Object>

Available on PictureSelectionItemModel, provided by the PictureSelectionItemModelEx extension

no setter
imageUrl → String?

Available on PictureSelectionItemModel, provided by the PictureSelectionItemModelEx extension

获取网络的URL
no setter
isLocalFile → bool

Available on PictureSelectionItemModel, provided by the PictureSelectionItemModelEx extension

是否为本地磁盘文件的图片
no setter
isNetworkUrl → bool

Available on PictureSelectionItemModel, provided by the PictureSelectionItemModelEx extension

no setter
localFilePath → File?

Available on PictureSelectionItemModel, provided by the PictureSelectionItemModelEx extension

获取本地的路径
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited