RequestParams class sealed

Available extensions
Annotations
  • @freezed

Constructors

RequestParams({@Default.new(true) bool showErrorMsg, @Default.new("loading...") String loadingText, String? contentType, @Default.new({}) Map<String, dynamic> headers, @Default.new(true) bool showDefaultLoading, dynamic data, ResponseType? responseType, bool? nullParams, RequestEncoder? requestEncoder, DioStart? dioStart, bool? returnIsString, String? fullUrl, InterceptorCall? interceptorCall, UrlParseFormat? urlParseFormat, ResponseResultCallback? responseResultCallback, Map<String, dynamic>? extra, CancelToken? cancelToken, ProgressCallback? onSendCallback, ProgressCallback? onReceiveProgress, String? downloadUrl, File? savePath})
const
factory
RequestParams.fromJson(Map<String, dynamic> json)
factory

Properties

cancelToken → CancelToken?
no setterinherited
contentType → String?
no setterinherited
copyWith → $RequestParamsCopyWith<RequestParams>
Create a copy of RequestParams with the given fields replaced by the non-null parameter values.
no setterinherited
data → dynamic
no setterinherited
dataModel → DartTypeModel

Available on RequestParams, provided by the RequestParamsex extension

no setter
dioStart → DioStart?
no setterinherited
downloadUrl → String?
no setterinherited
extra → Map<String, dynamic>?
no setterinherited
fullUrl → String?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
headers → Map<String, dynamic>
no setterinherited
interceptorCall → InterceptorCall?
no setterinherited
loadingText → String
no setterinherited
nullParams → bool?
no setterinherited
onReceiveProgress → ProgressCallback?
no setterinherited
onSendCallback → ProgressCallback?
no setterinherited
requestEncoder → RequestEncoder?
no setterinherited
responseResultCallback → ResponseResultCallback?
no setterinherited
responseType → ResponseType?
no setterinherited
returnIsString → bool?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
savePath → File?
no setterinherited
showDefaultLoading → bool
no setterinherited
showErrorMsg → bool
no setterinherited
urlParseFormat → UrlParseFormat?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this RequestParams to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited