AppSettingCache class

Inheritance

Constructors

AppSettingCache()
factory

Properties

boxName → String
no setteroverride
defaultBoxName → String
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
localSetting → Future<AppLocalSettingModel>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
themeKey ↔ String
getter/setter pair

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
boxAction(CacheBaseBoxHandle<AppLocalSettingModel> handle) → Future<void>
inherited
changeTheme(int index) → Future<void>
closeBox() → Future<void>
inherited
deleteByKey(dynamic key) → Future<void>
inherited
dispose() → void
Discards any resources used by the object.
inherited
getValue(String key, {AppLocalSettingModel? defaultValue}) → Future<AppLocalSettingModel?>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
openBox() → Future<Box<AppLocalSettingModel>>
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
saveAndUpdate(AppLocalSettingModel? handle(AppLocalSettingModel? oldValue), [String key = 'default', AppLocalSettingModel? defaultValue]) → Future<AppLocalSettingModel?>
inherited
setValue(String key, AppLocalSettingModel value) → Future<void>
inherited
toString() → String
A string representation of this object.
inherited
updateAllValue(ValueCopyWith<AppLocalSettingModel> update) → Future<void>
修改全部
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited