SearchSupportManager class sealed

Annotations
  • @freezed

Constructors

SearchSupportManager({required BuildContext context, required StateSetter floatStateSetter, required State<StatefulWidget> floatState})
const
factory

Properties

context → BuildContext
no setterinherited
copyWith → $SearchSupportManagerCopyWith<SearchSupportManager>
Create a copy of SearchSupportManager with the given fields replaced by the non-null parameter values.
no setterinherited
floatState → State<StatefulWidget>
no setterinherited
floatStateSetter → StateSetter
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited